==> aria2_1.13.0.orig.tar.gz: aria2-1.13.0/src/LibnettleARC4Encryptor.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2011 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "LibnettleARC4Encryptor.h"

#include <cassert>

namespace aria2 {

ARC4Encryptor::ARC4Encryptor() {}

ARC4Encryptor::~ARC4Encryptor() {}

void ARC4Encryptor::init(const unsigned char* key, size_t keyLength)
{
  ctx_.init(key, keyLength);
}

void ARC4Encryptor::encrypt(unsigned char* out, size_t outLength,
                            const unsigned char* in, size_t inLength)
{
  assert(outLength == inLength);
  arcfour_crypt(ctx_.getCipherContext(), outLength, out, in);
}

} // namespace aria2

==> aria2_1.25.0.orig.tar.gz: aria2-1.25.0/src/LibnettleARC4Encryptor.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2011 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "LibnettleARC4Encryptor.h"

namespace aria2 {

ARC4Encryptor::ARC4Encryptor() {}

ARC4Encryptor::~ARC4Encryptor() {}

void ARC4Encryptor::init(const unsigned char* key, size_t keyLength)
{
  arcfour_set_key(&ctx_, keyLength, key);
}

void ARC4Encryptor::encrypt(size_t len, unsigned char* out,
                            const unsigned char* in)
{
  arcfour_crypt(&ctx_, len, out, in);
}

} // namespace aria2
